Пакет Python3 для сохранения/извлечения данных по ключу.

### Как это работает

Данные в неизменном виде записываются в текстовый файл общим потоком. Ключи, идентифицирующие эти данные, в виде хешей сохраняются в бинарном файле. Причем при добавлении каждого нового хеша производится сортировка файла, чтобы в дальнейшем можно было использовать бинарный поиск. Для каждого типа данных в папке скрипта создается своя директория (то есть можно одновременно хранить разные виды данных).

### Установка

<code>pip install jbird</code>

### Пример использования

<code>from jbird.Jbird import *</code><br />
<br />
<code>user = Jbird('./users/')</code><br />
<code>cash = Jbird('./cash/')</code><br />
<br />
<code>user.set('1', 'John Dow')</code><br />
<code>cash.set('1', '100')</code><br />
<br />
<code>name = user.get('1')</code><br />
<code>pay = cash.get('1')</code><br />
